PlatformIsOS extension

Shorthands for checking operating system on the native platform.

Extension getters on Platform which forward to the operating system checks on Platform.nativePlatform, after checking that this is a native platform.

Not currently directly callabke because Platform has instance members with the same behavior, but may become useful if those can be removed

on

Properties

isAndroid → bool

Available on Platform, provided by the PlatformIsOS extension

Whether this is a nativePlatform with NativePlatform.isAndroid.
no setter
isFuchsia → bool

Available on Platform, provided by the PlatformIsOS extension

Whether this is a nativePlatform with NativePlatform.isFuchsia.
no setter
isIOS → bool

Available on Platform, provided by the PlatformIsOS extension

Whether this is a nativePlatform with NativePlatform.isIOS.
no setter
isLinux → bool

Available on Platform, provided by the PlatformIsOS extension

Whether this is a nativePlatform with NativePlatform.isLinux.
no setter
isMacOS → bool

Available on Platform, provided by the PlatformIsOS extension

Whether this is a nativePlatform with NativePlatform.isMacOS.
no setter
isWindows → bool

Available on Platform, provided by the PlatformIsOS extension

Whether this is a nativePlatform with NativePlatform.isWindows.
no setter